#include "xzdma.h"

XZDma_Config XZDma_ConfigTable[] __attribute__ ((section (".drvcfg_sec"))) = {

	{
		"amd,versal2-dma-1.0", /* compatible */
		0xebd00000, /* reg */
		0x1, /* xlnx,dma-mode */
		0x1, /* dma-coherent */
		0x4048, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"amd,versal2-dma-1.0", /* compatible */
		0xebd10000, /* reg */
		0x1, /* xlnx,dma-mode */
		0x1, /* dma-coherent */
		0x4049, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"amd,versal2-dma-1.0", /* compatible */
		0xebd20000, /* reg */
		0x1, /* xlnx,dma-mode */
		0x1, /* dma-coherent */
		0x404a, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"amd,versal2-dma-1.0", /* compatible */
		0xebd30000, /* reg */
		0x1, /* xlnx,dma-mode */
		0x1, /* dma-coherent */
		0x404b, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"amd,versal2-dma-1.0", /* compatible */
		0xebd40000, /* reg */
		0x1, /* xlnx,dma-mode */
		0x1, /* dma-coherent */
		0x404c, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"amd,versal2-dma-1.0", /* compatible */
		0xebd50000, /* reg */
		0x1, /* xlnx,dma-mode */
		0x1, /* dma-coherent */
		0x404d, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"amd,versal2-dma-1.0", /* compatible */
		0xebd60000, /* reg */
		0x1, /* xlnx,dma-mode */
		0x1, /* dma-coherent */
		0x404e, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"amd,versal2-dma-1.0", /* compatible */
		0xebd70000, /* reg */
		0x1, /* xlnx,dma-mode */
		0x1, /* dma-coherent */
		0x404f, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	 {
		 NULL
	}
};